@@ -1,3 +1,10 @@
+try:
+    import importlib.resources as pkg_resources
+except ImportError:
+    # Try backported to PY<37 `importlib_resources`.
+    # We support down to Python 3.6 so this is needed to prevent breaking change
+    import importlib_resources as pkg_resources
+import linter_configs
 import logging
 import json
 import os
@@ -6,6 +13,10 @@ import sys
 import yaml
 from typing import Optional
 
+from yamllint.cli import show_problems
+from yamllint.config import YamlLintConfig
+from yamllint import linter
+
 EXPECTED_TF_CONFIG_FILE_NAMES = ["tdfconfig.yml", "tdfconfig.yaml", "validate_configs.yaml", "commit_configs.yaml"]
 TRANSFORM_API_URL = "https://web-api.prod.transformdata.io"
 UPLOAD_MODE_VALIDATE = "validate"
@@ -47,6 +58,19 @@ def read_config_files(config_dir: str):
     return results
 
 
+def lint_transform_configs(config_dir: str):
+    """Run the python yamllinter on all metric configs"""
+    linter_config = pkg_resources.read_text(linter_configs, "yaml_linter_config.yaml")
+    conf = YamlLintConfig(content=linter_config)
+    max_level = 0
+    for _, fdata in read_config_files(config_dir).items():
+        problems = linter.run(fdata, conf, "")
+        level = show_problems(problems, "stdin", args_format="colored", no_warn=False)
+        max_level = max(max_level, level)
+    if max_level == linter.PROBLEM_LEVELS["error"]:
+        raise Exception("Python yamllint linter failed. See console output above for errors")
+
+
 def upload_configs(  # noqa: D
     mode: str,
     api_key: str,
@@ -56,13 +80,23 @@ def upload_configs(  # noqa: D
     config_dir: Optional[str] = None,
     api_url: Optional[str] = None,
 ) -> requests.Response:
-    yaml_files = read_config_files(config_dir or ".")
+
+    config_dir_to_use = config_dir or "."
+    # run python yaml linter in order to assert configs are following correct yaml syntax.
+    # this is to avoid adhoc debugging for config writers later.
+    lint_transform_configs(config_dir_to_use)
+
+    yaml_files = read_config_files(config_dir_to_use)
     results = {"yaml_files": yaml_files}
     logger.info(f"Files to upload: {yaml_files.keys()}")
     headers = {"Content-Type": "application/json", "Authorization": f"X-Api-Key {api_key}"}
     url = api_url or TRANSFORM_API_URL
     verify = url.startswith("https")
 
+    # because people like to put slashes in their branch names
+    if "/" in branch:
+        branch = branch.replace("/", "__")  # dunder, for readability... to the extent it matters
+
     add_files_url = f"{url}/api/v1/model/{repo}/{branch}/{commit}/add_model_files"
     logger.info(f"add_files_url: {add_files_url}")
     logger.info("Uploading config files")
@@ -108,11 +142,12 @@ if __name__ == "__main__":
     else:
         BRANCH = os.getenv("GITHUB_HEAD_REF")
 
+    API_URL = os.getenv("TRANSFORM_API_URL", TRANSFORM_API_URL)
     COMMIT = os.getenv("GITHUB_SHA")
     TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR")
     if TRANSFORM_CONFIG_DIR:
         TRANFSFORM_CONFIG_DIR = TRANSFORM_CONFIG_DIR.lstrip().rstrip()
     TRANSFORM_API_KEY = os.environ["TRANSFORM_API_KEY"].lstrip().rstrip()  # fail if TRANSFORM_API_KEY not present
 
-    upload_configs(mode, TRANSFORM_API_KEY, REPO, BRANCH, COMMIT, TRANSFORM_CONFIG_DIR)
+    upload_configs(mode, TRANSFORM_API_KEY, REPO, BRANCH, COMMIT, TRANSFORM_CONFIG_DIR, API_URL)
     print("success")
